Abstracts
---------

Problematic
^^^^^^^^^^^

How can we work with abstracted data and information which are
not directly related to our project main logic?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.abstracts
   :members:
   :private-members:


:code:`Infrastructure()`
""""""""""""""""""""""""

.. autoclass:: PyFunceble.abstracts.infrastructure.Infrastructure
    :members:
    :private-members:


:code:`Package()`
"""""""""""""""""

.. autoclass:: PyFunceble.abstracts.package.Package
    :members:
    :private-members:

:code:`Platform()`
""""""""""""""""""

.. autoclass:: PyFunceble.abstracts.platform.Platform
    :members:
    :private-members:


:code:`Version()`
"""""""""""""""""

.. autoclass:: PyFunceble.abstracts.package.Version
    :members:
    :private-members:
